First of the patches that fixes the lines over 80 characters in reg.c

Signed-off-by: Iker Pedrosa <ikerpedro...@gmail.com>
---
 drivers/staging/winbond/reg.c | 26 ++++++++++----------------
 1 file changed, 10 insertions(+), 16 deletions(-)

diff --git a/drivers/staging/winbond/reg.c b/drivers/staging/winbond/reg.c
index c023fda..429c28e 100644
--- a/drivers/staging/winbond/reg.c
+++ b/drivers/staging/winbond/reg.c
@@ -809,12 +809,7 @@ u32 w89rf242_txvga_data[][5] = {
        {(0x05 << 24) | 0x24C7CA, 34, 0x00292315, 0x0800FEFF, 0x72724242}
 };
 
-/* 
==================================================================================================
 */
-
-
-
 /*
- * 
=============================================================================================================
  *  Uxx_ReadEthernetAddress --
  *
  *  Routine Description:
@@ -826,15 +821,15 @@ u32 w89rf242_txvga_data[][5] = {
  *  Return Value:
  *
  *    The address is stored in EthernetIDAddr.
- * 
=============================================================================================================
  */
 void Uxx_ReadEthernetAddress(struct hw_data *pHwData)
 {
        u32     ltmp;
 
        /*
-        * Reading Ethernet address from EEPROM and set into hardware due to 
MAC address maybe change.
         * Only unplug and plug again can make hardware read EEPROM again.
         */
        Wb35Reg_WriteSync(pHwData, 0x03b4, 0x08000000); /* Start EEPROM access 
+ Read + address(0x0d) */
        Wb35Reg_ReadSync(pHwData, 0x03b4, &ltmp);
@@ -852,18 +847,17 @@ void Uxx_ReadEthernetAddress(struct hw_data *pHwData)
 
 
 /*
- * 
===============================================================================================================
  *  CardGetMulticastBit --
  *  Description:
- *    For a given multicast address, returns the byte and bit in the card 
multicast registers that it hashes to.
  *    Calls CardComputeCrc() to determine the CRC value.
  *  Arguments:
  *    Address - the address
  *    Byte - the byte that it hashes to
  *    Value - will have a 1 in the relevant bit
  *  Return Value:
  *    None.
- * 
==============================================================================================================
  */
 void CardGetMulticastBit(u8 Address[ETH_ALEN], u8 *Byte, u8 *Value)
 {
@@ -926,7 +920,8 @@ static void Set_ChanIndep_RfData_al7230_24(struct hw_data 
*pHwData, u32 *pltmp,
        u8      i;
        for (i = 0; i < number; i++) {
                pHwData->phy_para[i] = al7230_rf_data_24[i];
-               pltmp[i] = (1 << 31) | (0 << 30) | (24 << 24) | 
(al7230_rf_data_24[i] & 0xffffff);
+               pltmp[i] = (1 << 31) | (0 << 30) | (24 << 24) |
+                          (al7230_rf_data_24[i] & 0xffffff);
        }
 }
 
@@ -936,15 +931,14 @@ static void Set_ChanIndep_RfData_al7230_50(struct hw_data 
*pHwData, u32 *pltmp,
        u8      i;
        for (i = 0; i < number; i++) {
                pHwData->phy_para[i] = al7230_rf_data_50[i];
-               pltmp[i] = (1 << 31) | (0 << 30) | (24 << 24) | 
(al7230_rf_data_50[i] & 0xffffff);
+               pltmp[i] = (1 << 31) | (0 << 30) | (24 << 24)
+                                  | (al7230_rf_data_50[i] & 0xffffff);
        }
 }
 
 
 /*
- * 
=============================================================================================================
  * RFSynthesizer_initial --
- * 
=============================================================================================================
  */
 void RFSynthesizer_initial(struct hw_data *pHwData)
@@ -826,15 +821,15 @@ u32 w89rf242_txvga_data[][5] = {
MAC address maybe change.
-        * Only unplug and plug again can make hardware read EEPROM again.
+        * Reading Ethernet address from EEPROM and set into hardware due to
+        * MAC address maybe change. Only unplug and plug again can make
+        * hardware read EEPROM again.
         */
        Wb35Reg_WriteSync(pHwData, 0x03b4, 0x08000000); /* Start EEPROM access 
@@ -852,18 +847,17 @@ void Uxx_ReadEthernetAddress(struct hw_data *pHwData)
multicast registers that it hashes to.
- *    Calls CardComputeCrc() to determine the CRC value.
+ *    For a given multicast address, returns the byte and bit in the card
+ *    multicast registers that it hashes to. Calls CardComputeCrc() to
+ *    determine the CRC value.
  *  Arguments:
  *    Address - the address
 {
-- 
1.8.1.2

_______________________________________________
devel mailing list
de...@linuxdriverproject.org
http://driverdev.linuxdriverproject.org/mailman/listinfo/driverdev-devel

Reply via email to